pub struct NetworkExportTableItem {
    pub remote_network: NetworkId,
    pub remote_location_filter: Option<Vec<InteriorMultiLocation>>,
    pub bridge: MultiLocation,
    pub payment: Option<MultiAsset>,
}
Configuration item representing a single exporter in the NetworkExportTable.

Fields

remote_network: NetworkId

Supported remote network.

remote_location_filter: Option<Vec<InteriorMultiLocation>>

Remote location filter. If Some, the requested remote location must be equal to one of the items in the vector. These are locations in the remote network. If None, then the check is skipped.

bridge: MultiLocation

Locally-routable bridge with bridging capabilities to the remote_network and remote_location. See ExporterFor for more details.

payment: Option<MultiAsset>

The local payment. See ExporterFor for more details.

Implementations

source

impl NetworkExportTableItem

source

pub fn new( remote_network: NetworkId, remote_location_filter: Option<Vec<InteriorMultiLocation>>, bridge: MultiLocation, payment: Option<MultiAsset> ) -> Self