Struct staging_xcm_builder::WithTopicSource
source · pub struct WithTopicSource<Inner, TopicSource>(/* private fields */);Expand description
Wrapper router which, if the message does not already end with a SetTopic instruction,
prepends one to the message filled with an ID from TopicSource. This ID is returned from a
successful deliver.
This is designed to be at the top-level of any routers, since it will always mutate the
passed message reference into a None. Don’t try to combine it within a tuple except as the
last element.