Struct staging_xcm_builder::WithUniqueTopic
source · pub struct WithUniqueTopic<Inner>(/* private fields */);Expand description
Wrapper router which, if the message does not already end with a SetTopic instruction,
appends one to the message filled with a universally unique ID. This ID is returned from a
successful deliver.
If the message does already end with a SetTopic instruction, then it is the responsibility
of the code author to ensure that the ID supplied to SetTopic is universally unique. Due to
this property, consumers of the topic ID must be aware that a user-supplied ID may not be
unique.
This is designed to be at the top-level of any routers, since it will always mutate the
passed message reference into a None. Don’t try to combine it within a tuple except as the
last element.