pub enum BodyPart {
Voice,
Members {
count: u32,
},
Fraction {
nom: u32,
denom: u32,
},
AtLeastProportion {
nom: u32,
denom: u32,
},
MoreThanProportion {
nom: u32,
denom: u32,
},
}Expand description
A part of a pluralistic body.
Variants
Voice
The body’s declaration, under whatever means it decides.
Members
A given number of members of the body.
Fraction
A given number of members of the body, out of some larger caucus.
AtLeastProportion
No less than the given proportion of members of the body.
MoreThanProportion
More than the given proportion of members of the body.
Implementations