pub enum Outcome {
Complete {
used: Weight,
},
Incomplete {
used: Weight,
error: InstructionError,
},
Error(InstructionError),
}Expand description
Outcome of an XCM execution.
Variants
Complete
Execution completed successfully; given weight was used.
Incomplete
Execution started, but did not complete successfully due toerror which occurred
on the index-th (top-level) instruction. Overall, total weight was used.
Error(InstructionError)
Execution did not start due to an error. We use InstructionError since it’s always
possible to isolate the problematic instruction that caused the error.
Implementations
Sourceimpl Outcome
impl Outcome
pub fn ensure_complete(self) -> Result<(), InstructionError>
pub fn ensure_execution(self) -> Result<Weight, InstructionError>
Sourcepub fn weight_used(&self) -> Weight
pub fn weight_used(&self) -> Weight
How much weight was used by the XCM execution attempt.