pub enum WildAsset {
All,
AllOf {
id: AssetId,
fun: WildFungibility,
},
AllCounted(u32),
AllOfCounted {
id: AssetId,
fun: WildFungibility,
count: u32,
},
}Expand description
A wildcard representing a set of assets.
Variants
All
All assets in Holding.
AllOf
All assets in Holding of a given fungibility and ID.
AllCounted(u32)
All assets in Holding, up to u32 individual assets (different instances of non-fungibles
are separate assets).
AllOfCounted
All assets in Holding of a given fungibility and ID up to count individual assets
(different instances of non-fungibles are separate assets).
Implementations
Sourceimpl WildAsset
impl WildAsset
Sourcepub fn contains(&self, inner: &Asset) -> bool
pub fn contains(&self, inner: &Asset) -> bool
Returns true if self is a super-set of the given inner asset.
Sourcepub fn matches(&self, inner: &Asset) -> bool
👎Deprecated: Use contains instead
pub fn matches(&self, inner: &Asset) -> bool
contains insteadReturns true if the wild element of self matches inner.
Note that for Counted variants of wildcards, then it will disregard the count except for
always returning false when equal to 0.
Sourcepub fn reanchor(
&mut self,
target: &Location,
context: &Junctions,
) -> Result<(), ()>
pub fn reanchor( &mut self, target: &Location, context: &Junctions, ) -> Result<(), ()>
Mutate the asset to represent the same value from the perspective of a new target
location. The local chain’s location is provided in context.