Struct staging_xcm_builder::test_utils::MultiAsset
source · pub struct MultiAsset {
pub id: AssetId,
pub fun: Fungibility,
}Expand description
Either an amount of a single fungible asset, or a single well-identified non-fungible asset.
Fields
id: AssetIdThe overall asset identity (aka class, in the case of a non-fungible).
fun: FungibilityThe fungibility of the asset, which contains either the amount (in the case of a fungible asset) or the instance ID, the secondary asset identifier.
Implementations
sourceimpl MultiAsset
impl MultiAsset
pub fn is_fungible(&self, maybe_id: Option<AssetId>) -> bool
pub fn is_non_fungible(&self, maybe_id: Option<AssetId>) -> bool
sourcepub fn prepend_with(&mut self, prepend: &MultiLocation) -> Result<(), ()>
pub fn prepend_with(&mut self, prepend: &MultiLocation) -> Result<(), ()>
Prepend a MultiLocation to a concrete asset, giving it a new root location.
sourcepub fn reanchor(
&mut self,
target: &MultiLocation,
context: Junctions
) -> Result<(), ()>
pub fn reanchor( &mut self, target: &MultiLocation, context: Junctions ) -> Result<(), ()>
Mutate the location of the asset identifier if concrete, giving it the same location
relative to a target context. The local context is provided as context.
sourcepub fn reanchored(
self,
target: &MultiLocation,
context: Junctions
) -> Result<MultiAsset, ()>
pub fn reanchored( self, target: &MultiLocation, context: Junctions ) -> Result<MultiAsset, ()>
Mutate the location of the asset identifier if concrete, giving it the same location
relative to a target context. The local context is provided as context.
sourcepub fn contains(&self, inner: &MultiAsset) -> bool
pub fn contains(&self, inner: &MultiAsset) -> bool
Returns true if self is a super-set of the given inner asset.