pub struct TestAssetLocker;Trait Implementations
Sourceimpl AssetLock for TestAssetLocker
impl AssetLock for TestAssetLocker
Sourcetype LockTicket = TestLockTicket
type LockTicket = TestLockTicket
Enact implementer for prepare_lock. This type may be dropped safely to avoid doing the
lock.Sourcetype UnlockTicket = TestUnlockTicket
type UnlockTicket = TestUnlockTicket
Enact implementer for prepare_unlock. This type may be dropped safely to avoid doing the
unlock.Sourcetype ReduceTicket = TestReduceTicket
type ReduceTicket = TestReduceTicket
Enact implementer for prepare_reduce_unlockable. This type may be dropped safely to
avoid doing the unlock.Sourcefn prepare_lock(
unlocker: Location,
asset: Asset,
_owner: Location,
) -> Result<TestLockTicket, LockError>
fn prepare_lock( unlocker: Location, asset: Asset, _owner: Location, ) -> Result<TestLockTicket, LockError>
Prepare to lock an asset. On success, a
Self::LockTicket it returned, which can be used
to actually enact the lock. Read moreSourcefn prepare_unlock(
unlocker: Location,
asset: Asset,
_owner: Location,
) -> Result<TestUnlockTicket, LockError>
fn prepare_unlock( unlocker: Location, asset: Asset, _owner: Location, ) -> Result<TestUnlockTicket, LockError>
Prepare to unlock an asset. On success, a
Self::UnlockTicket it returned, which can be
used to actually enact the lock. Read moreSourcefn note_unlockable(
_locker: Location,
_asset: Asset,
_owner: Location,
) -> Result<(), LockError>
fn note_unlockable( _locker: Location, _asset: Asset, _owner: Location, ) -> Result<(), LockError>
Handler for when a location reports to us that an asset has been locked for us to unlock
at a later stage. Read more
Sourcefn prepare_reduce_unlockable(
_locker: Location,
_asset: Asset,
_owner: Location,
) -> Result<TestReduceTicket, LockError>
fn prepare_reduce_unlockable( _locker: Location, _asset: Asset, _owner: Location, ) -> Result<TestReduceTicket, LockError>
Handler for when an owner wishes to unlock an asset on a remote chain. Read more